@@ -2,7 +2,7 @@
     libpe - the PE library
 
     Copyright (C) 2010 - 2017 libpe authors
-    
+
     This file is part of libpe.
 
     libpe is free software: you can redistribute it and/or modify
@@ -63,7 +63,7 @@ pe_err_e pe_load_file_ext(pe_ctx_t *ctx, const char *path, pe_options_e options)
 	}
 
 	int ret = 0;
-	
+
 	// Stat the fd to retrieve the file informations.
 	// If file is a symlink, fstat will stat the pointed file, not the link.
 	struct stat stat;
@@ -184,6 +184,8 @@ pe_err_e pe_parse(pe_ctx_t *ctx) {
 	    		//fprintf(stderr, "Invalid signature: %x\n", ctx->pe.signature);
 	    		return LIBPE_E_INVALID_SIGNATURE;
 	    	case SIGNATURE_PE:
+	    	case SIGNATURE_PL:
+	    	case SIGNATURE_PX:
 	    		break;
 	    }
 
@@ -230,6 +232,7 @@ pe_err_e pe_parse(pe_ctx_t *ctx) {
 			ctx->pe.optional_hdr.length = sizeof(IMAGE_ROM_OPTIONAL_HEADER);
 			ctx->pe.entrypoint = ctx->pe.optional_hdr._rom->AddressOfEntryPoint;
 			break;
+		case MAGIC_PE32_0:
 		case MAGIC_PE32:
 			if (ctx->pe.coff_hdr->SizeOfOptionalHeader <
 			    sizeof(IMAGE_OPTIONAL_HEADER_32))
@@ -342,7 +345,7 @@ bool pe_is_exec(const pe_ctx_t *ctx) {
 		return false;
 
 	// Check PE signature
-	if (ctx->pe.signature != SIGNATURE_PE)
+	if (ctx->pe.signature != SIGNATURE_PE && ctx->pe.signature != SIGNATURE_PL && ctx->pe.signature != SIGNATURE_PX)
 		return false;
 
 	return true;
@@ -570,6 +573,7 @@ const char *pe_machine_type_name(MachineType type) {
 		LIBPE_ENTRY(IMAGE_FILE_MACHINE_SH4),
 		LIBPE_ENTRY(IMAGE_FILE_MACHINE_SH5),
 		LIBPE_ENTRY(IMAGE_FILE_MACHINE_TRICORE),
+		LIBPE_ENTRY(IMAGE_FILE_MACHINE_TAHOE),
 		LIBPE_ENTRY(IMAGE_FILE_MACHINE_THUMB),
 		LIBPE_ENTRY(IMAGE_FILE_MACHINE_WCEMIPSV2)
 	};
@@ -871,3 +875,25 @@ const char *pe_rom_section_characteristic_name(ROMSectionCharacteristics charact
 bool pe_use_rom_section_characteristic(pe_ctx_t *ctx) {
 	return ctx->pe.optional_hdr_ptr != NULL && ctx->pe.optional_hdr.type == MAGIC_ROM;
 }
+
+bool pe_is_repro(pe_ctx_t *ctx) {
+	const IMAGE_DATA_DIRECTORY *dir = pe_directory_by_entry(ctx, IMAGE_DIRECTORY_ENTRY_DEBUG);
+	if (dir == NULL)
+		return false;
+
+	uint64_t va = dir->VirtualAddress;
+	if (va == 0)
+		return false;
+
+	uint64_t ofs = pe_rva2ofs(ctx, va);
+	const IMAGE_DEBUG_DIRECTORY *debugs = LIBPE_PTR_ADD(ctx->map_addr, ofs);
+	uint32_t count = dir->Size / sizeof(debugs[0]);
+	for (uint32_t i = 0; i < count; i++) {
+		if (!pe_can_read(ctx, &debugs[i], sizeof(debugs[i])))
+			return false;
+		if (debugs[i].Type == IMAGE_DEBUG_TYPE_REPRO)
+			return true;
+	}
+
+	return false;
+}
